==> tencent_im_sdk_mobile-0.0.1.tar.gz: lib/src/group.dart <==
import 'package:tencent_im_sdk_platform_interface/tencent_im_sdk_platform_interface.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_callback.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';

TIMGroupTypeToString(TIMGroupType type) {
  return ['Work', 'Public', 'Meeting', 'Meeting', 'AVChatRoom'][type.index];
}

class GroupManagerMobile extends GroupManagerPlatform {
  @override
  void init() {}

  @override
  Future<String> createGroup({
    String? groupId,
    required groupName,
    required TIMGroupType groupType,
    List<String>? memberList, //TODO memberList 未实现
    String notification = '',
    String introduction = '',
    String faceUrl = '',
    TIMGroupAddOption addOption = TIMGroupAddOption.any,
    bool isAllMuted = false,
  }) async {
    V2TimValueCallback<String> res = await TencentImSDKPlugin.v2TIMManager.getGroupManager().createGroup(
          groupType: TIMGroupTypeToString(groupType),
          groupName: groupName,
          groupID: groupId,
          notification: notification,
          introduction: introduction,
          isAllMuted: isAllMuted,
          faceUrl: faceUrl,
          addOpt: addOption.index,
        );

    if (res.code != 0) {
      throw (CreateGroupException(res.code, res.desc));
    }

    return res.data ?? '';
  }

  @override
  Future<void> dissolveGroup({required String groupId}) async {
    V2TimCallback res = await TencentImSDKPlugin.v2TIMManager.dismissGroup(
      groupID: groupId,
    );

    if (res.code != 0) {
      throw (DissolveGroupException(res.code, res.desc));
    }
  }

  @override
  Future<void> joinGroup({required String groupId, String helloMessage = ''}) async {
    V2TimCallback res = await TencentImSDKPlugin.v2TIMManager.joinGroup(
      groupID: groupId,
      message: helloMessage,
    );

    if (res.code != 0) {
      throw (JoinGroupException(res.code, res.desc));
    }
  }

  @override
  Future<void> quitGroup({required String groupId}) async {
    V2TimCallback res = await TencentImSDKPlugin.v2TIMManager.quitGroup(
      groupID: groupId,
    );

    if (res.code != 0) {
      throw (JoinGroupException(res.code, res.desc));
    }
  }
}

==> tencent_im_sdk_mobile-0.0.3.tar.gz: lib/src/group.dart <==
import 'package:tencent_im_sdk_platform_interface/tencent_im_sdk_platform_interface.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_callback.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';

TIMGroupTypeToString(TIMGroupType type) {
  return ['Work', 'Public', 'Meeting', 'Meeting', 'AVChatRoom'][type.index];
}

class GroupManager extends GroupManagerPlatform {
  @override
  void init() {}

  @override
  Future<String> createGroup({
    String? groupId,
    required groupName,
    required TIMGroupType groupType,
    List<String>? memberList, //TODO memberList 未实现
    String notification = '',
    String introduction = '',
    String faceUrl = '',
    TIMGroupAddOption addOption = TIMGroupAddOption.any,
    bool isAllMuted = false,
  }) async {
    V2TimValueCallback<String> res = await TencentImSDKPlugin.v2TIMManager.getGroupManager().createGroup(
          groupType: TIMGroupTypeToString(groupType),
          groupName: groupName,
          groupID: groupId,
          notification: notification,
          introduction: introduction,
          isAllMuted: isAllMuted,
          faceUrl: faceUrl,
          addOpt: addOption.index,
        );

    if (res.code != 0) {
      throw (CreateGroupException(res.code, res.desc));
    }

    return res.data ?? '';
  }

  @override
  Future<void> dissolveGroup({required String groupId}) async {
    V2TimCallback res = await TencentImSDKPlugin.v2TIMManager.dismissGroup(
      groupID: groupId,
    );

    if (res.code != 0) {
      throw (DissolveGroupException(res.code, res.desc));
    }
  }

  @override
  Future<void> joinGroup({required String groupId, String helloMessage = ''}) async {
    V2TimCallback res = await TencentImSDKPlugin.v2TIMManager.joinGroup(
      groupID: groupId,
      message: helloMessage,
    );

    if (res.code != 0) {
      throw (JoinGroupException(res.code, res.desc));
    }
  }

  @override
  Future<void> quitGroup({required String groupId}) async {
    V2TimCallback res = await TencentImSDKPlugin.v2TIMManager.quitGroup(
      groupID: groupId,
    );

    if (res.code != 0) {
      throw (JoinGroupException(res.code, res.desc));
    }
  }
}
